==> openshift-model-monitoring-5.11.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SlackActionBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionBuilder>{
  public SlackActionBuilder() {
    this(false);
  }
  public SlackActionBuilder(java.lang.Boolean validationEnabled) {
    this(new SlackAction(), validationEnabled);
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SlackAction(), validationEnabled);
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction instance) {
    this(fluent, instance, false);
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfirm(instance.getConfirm()); 
    fluent.withName(instance.getName()); 
    fluent.withStyle(instance.getStyle()); 
    fluent.withText(instance.getText()); 
    fluent.withType(instance.getType()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction instance) {
    this(instance,false);
  }
  public SlackActionBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfirm(instance.getConfirm()); 
    this.withName(instance.getName()); 
    this.withStyle(instance.getStyle()); 
    this.withText(instance.getText()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackActionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.SlackAction build() {
    SlackAction buildable = new SlackAction(fluent.getConfirm(),fluent.getName(),fluent.getStyle(),fluent.getText(),fluent.getType(),fluent.getUrl(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackActionBuilder that = (SlackActionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackActionBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SlackActionBuilder extends SlackActionFluentImpl<SlackActionBuilder> implements VisitableBuilder<SlackAction,SlackActionBuilder>{
  public SlackActionBuilder() {
    this(false);
  }
  public SlackActionBuilder(Boolean validationEnabled) {
    this(new SlackAction(), validationEnabled);
  }
  public SlackActionBuilder(SlackActionFluent<?> fluent) {
    this(fluent, false);
  }
  public SlackActionBuilder(SlackActionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SlackAction(), validationEnabled);
  }
  public SlackActionBuilder(SlackActionFluent<?> fluent,SlackAction instance) {
    this(fluent, instance, false);
  }
  public SlackActionBuilder(SlackActionFluent<?> fluent,SlackAction instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfirm(instance.getConfirm()); 
    fluent.withName(instance.getName()); 
    fluent.withStyle(instance.getStyle()); 
    fluent.withText(instance.getText()); 
    fluent.withType(instance.getType()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SlackActionBuilder(SlackAction instance) {
    this(instance,false);
  }
  public SlackActionBuilder(SlackAction instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfirm(instance.getConfirm()); 
    this.withName(instance.getName()); 
    this.withStyle(instance.getStyle()); 
    this.withText(instance.getText()); 
    this.withType(instance.getType()); 
    this.withUrl(instance.getUrl()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SlackActionFluent<?> fluent;
  Boolean validationEnabled;
  public SlackAction build() {
    SlackAction buildable = new SlackAction(fluent.getConfirm(),fluent.getName(),fluent.getStyle(),fluent.getText(),fluent.getType(),fluent.getUrl(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
